@@ -341,6 +341,9 @@ public:
 
     std::string modName;
 
+    // The mod-relative path to the file this DEF was declared in
+    std::string defFilename;
+
     IModelDef() :
         resolved(false),
         modName("base")
@@ -442,6 +445,11 @@ public:
      * Iterate over each ModelDef using the given visitor class.
      */
     virtual void forEachModelDef(ModelDefVisitor& visitor) = 0;
+
+    /**
+     * Iterate over each ModelDef using the given function object.
+     */
+    virtual void forEachModelDef(const std::function<void(const IModelDefPtr&)>& functor) = 0;
 };
 
 /**
