@@ -33,6 +33,12 @@ public:
 	 */
 	virtual IModelPtr getModel(const std::string& modelPath) = 0;
 
+	// This reloads all models in the map
+	virtual void refreshModels(bool blockScreenUpdates = true) = 0;
+
+	// This reloads all selected models in the map
+	virtual void refreshSelectedModels(bool blockScreenUpdates = true) = 0;
+
 	// Clears a specific model from the cache
 	virtual void removeModel(const std::string& modelPath) = 0;
 
@@ -49,10 +55,6 @@ const char* const MODULE_MODELCACHE("ModelCache");
 
 inline model::IModelCache& GlobalModelCache()
 {
-	static model::IModelCache& _modelCache(
-		*std::static_pointer_cast<model::IModelCache>(
-			module::GlobalModuleRegistry().getModule(MODULE_MODELCACHE)
-		)
-	);
-	return _modelCache;
+	static module::InstanceReference<model::IModelCache> _reference(MODULE_MODELCACHE);
+	return _reference;
 }
