@@ -7,6 +7,8 @@ template<typename Element>
 class BasicVector3;
 typedef BasicVector3<double> Vector3;
 
+const char* const RKEY_HIGHER_ENTITY_PRIORITY = "user/ui/xyview/higherEntitySelectionPriority";
+
 // Possible types of the orthogonal view window
 enum EViewType
 {
@@ -32,6 +34,12 @@ public:
         Default = Pointer,
     };
 
+    virtual const Vector3& getOrigin() const = 0;
+    virtual void setOrigin(const Vector3& origin) = 0;
+
+    virtual int getWidth() const = 0;
+    virtual int getHeight() const = 0;
+
     // Returns the scale factor of this view
     virtual float getScale() const = 0;
 
@@ -67,6 +75,18 @@ public:
 	// Sets the origin of all available views
 	virtual void setOrigin(const Vector3& origin) = 0;
 
+    // Returns the origin of the currently active ortho view
+    // Will throw std::runtime_error if no view is found
+    virtual Vector3 getActiveViewOrigin() = 0;
+
+    // Returns a reference to the currently active view
+    // Will throw std::runtime_error if no view is found
+    virtual IOrthoView& getActiveView() = 0;
+
+    // Return the first view matching the given viewType
+    // Will throw std::runtime_error if no view is found
+    virtual IOrthoView& getViewByType(EViewType viewType) = 0;
+
 	// Sets the scale of all available views
 	virtual void setScale(float scale) = 0;
 
@@ -90,11 +110,6 @@ const char* const MODULE_ORTHOVIEWMANAGER = "OrthoviewManager";
 // This is the accessor for the xy window manager module
 inline ui::IXWndManager& GlobalXYWndManager()
 {
-	// Cache the reference locally
-	static ui::IXWndManager& _xyWndManager(
-		*std::static_pointer_cast<ui::IXWndManager>(
-			module::GlobalModuleRegistry().getModule(MODULE_ORTHOVIEWMANAGER)
-		)
-	);
-	return _xyWndManager;
+    static module::InstanceReference<ui::IXWndManager> _reference(MODULE_ORTHOVIEWMANAGER);
+    return _reference;
 }
