@@ -19,6 +19,8 @@ class ObservedUndoable :
 	IUndoStateSaver* _undoStateSaver;
     IMapFileChangeTracker* _changeTracker;
 
+	std::string _debugName;
+
 public:
 	ObservedUndoable<Copyable>(Copyable& object, const ImportCallback& importCallback) :
 		_object(object), 
@@ -27,6 +29,14 @@ public:
         _changeTracker(nullptr)
 	{}
 
+	ObservedUndoable<Copyable>(Copyable& object, const ImportCallback& importCallback, const std::string& debugName) :
+		_object(object),
+		_importCallback(importCallback),
+		_undoStateSaver(nullptr),
+		_changeTracker(nullptr),
+		_debugName(debugName)
+	{}
+
     IMapFileChangeTracker& getUndoChangeTracker()
     {
         return *_changeTracker;
