@@ -16,6 +16,7 @@
 #include <cmath>
 #include <istream>
 #include <ostream>
+#include <sstream>
 
 #include <float.h>
 #include "math/pi.h"
@@ -98,16 +99,22 @@ public:
     const Element& y() const { return _v[1]; }
     const Element& z() const { return _v[2]; }
 
-    /** Compare this BasicVector3 against another for equality.
-     */
+    /// Return human readable debug string (pretty print)
+    std::string pp() const
+    {
+        std::stringstream ss;
+        ss << "[" << x() << ", " << y() << ", " << z() << "]";
+        return ss.str();
+    }
+
+    /// Compare this BasicVector3 against another for equality.
     bool operator== (const BasicVector3& other) const {
         return (other.x() == x()
                 && other.y() == y()
                 && other.z() == z());
     }
 
-    /** Compare this BasicVector3 against another for inequality.
-     */
+    /// Compare this BasicVector3 against another for inequality.
     bool operator!= (const BasicVector3& other) const {
         return !(*this == other);
     }
@@ -329,7 +336,8 @@ public:
      * The angle as defined by the arccos( (a*b) / (|a|*|b|) )
      */
     template<typename OtherT>
-    Element angle(const BasicVector3<OtherT>& other) const {
+    Element angle(const BasicVector3<OtherT>& other) const
+    {
         BasicVector3<Element> aNormalised = getNormalised();
         BasicVector3<OtherT> otherNormalised = other.getNormalised();
 
@@ -337,11 +345,16 @@ public:
 
         // greebo: Sanity correction: Make sure the dot product
         // of two normalised vectors is not greater than 1
-        if (dot > 1.0) {
+        if (dot > 1.0)
+        {
             dot = 1;
         }
+        else if (dot < -1.0)
+        {
+            dot = -1.0;
+        }
 
-        return acos( dot );
+        return acos(dot);
     }
 
     /* Cross-product this vector with another Vector3, returning the result
