@@ -32,7 +32,13 @@ private:
 	{
 		std::string caption;	// "Doom 3 Map (*.map)"
 		std::string filter;		// "*.map"
+		std::string extension;		// "map"
 		std::string mapFormatName;
+		bool isDefaultFilter;			// should be selected when dialog is shown
+
+		FileFilter() :
+			isDefaultFilter(false)
+		{}
 	};
 
 	std::vector<FileFilter> _fileFilters;
@@ -107,7 +113,12 @@ public:
 private:
 	static long getStyle(bool open);
 
+	void selectFilterIndexFromFilename(const std::string& filename);
+
 	void construct(); // shared constructor stuff
+
+	void assembleMapExportFileTypes();
+	void assembleFileTypes();
 };
 
 } // namespace wxutil
