@@ -3,6 +3,7 @@
 #include "igl.h"
 #include "math/Matrix4.h"
 #include <functional>
+#include "debugging/gl.h"
 
 namespace wxutil
 {
@@ -78,9 +79,9 @@ void GuiView::setGLViewPort()
 	debug::assertNoGlErrors();
 }
 
-void GuiView::draw()
+bool GuiView::draw()
 {
-	if (_gui == NULL) return;
+	if (!_gui) return false;
 
 	debug::assertNoGlErrors();
 
@@ -117,6 +118,8 @@ void GuiView::draw()
 	debug::assertNoGlErrors();
 
 	_renderer.render();
+
+	return true;
 }
 
 void GuiView::onSizeAllocate(wxSizeEvent& ev)
