@@ -34,7 +34,6 @@ public:
 
 		if (_dependencies.empty())
 		{
-			_dependencies.insert(MODULE_EVENTMANAGER);
 			_dependencies.insert(MODULE_UIMANAGER);
 			_dependencies.insert(MODULE_COMMANDSYSTEM);
 		}
@@ -42,13 +41,12 @@ public:
 		return _dependencies;
 	}
 
-	void initialiseModule(const ApplicationContext& ctx)
+	void initialiseModule(const IApplicationContext& ctx)
 	{
 		rMessage() << getName() << "::initialiseModule called." << std::endl;
 
 		// Add the callback event
 		GlobalCommandSystem().addCommand("DifficultyEditor",  ui::DifficultyDialog::ShowDialog);
-		GlobalEventManager().addCommand("DifficultyEditor", "DifficultyEditor");
 
 		// Add the menu item
 		IMenuManager& mm = GlobalUIManager().getMenuManager();
