@@ -25,33 +25,31 @@
 #include "iuimanager.h"
 #include "iarchive.h"
 
-
 class GuiModule :
 	public RegisterableModule,
 	public std::enable_shared_from_this<GuiModule>
 {
 public:
 	// RegisterableModule implementation
-	virtual const std::string& getName() const
+	const std::string& getName() const override
 	{
 		static std::string _name("GUI Editing");
 		return _name;
 	}
 
-	virtual const StringSet& getDependencies() const {
+	const StringSet& getDependencies() const override
+	{
 		static StringSet _dependencies;
 
 		if (_dependencies.empty())
 		{
 			_dependencies.insert(MODULE_COMMANDSYSTEM);
-			_dependencies.insert(MODULE_EVENTMANAGER);
 			_dependencies.insert(MODULE_FONTMANAGER);
 			_dependencies.insert(MODULE_GAMEMANAGER);
 			_dependencies.insert(MODULE_MAINFRAME);
 			_dependencies.insert(MODULE_MAP);
 			_dependencies.insert(MODULE_OPENGL);
 			_dependencies.insert(MODULE_PREFERENCESYSTEM);
-			_dependencies.insert(MODULE_RADIANT);
 			_dependencies.insert(MODULE_RENDERSYSTEM);
 			_dependencies.insert(MODULE_SHADERSYSTEM);
 			_dependencies.insert(MODULE_UIMANAGER);
@@ -62,25 +60,23 @@ public:
 		return _dependencies;
 	}
 
-	virtual void initialiseModule(const ApplicationContext& ctx)
+	void initialiseModule(const IApplicationContext& ctx) override
 	{
 		rMessage() << getName() << "::initialiseModule called." << std::endl;
 
 		GlobalCommandSystem().addCommand("ReadableEditorDialog", ui::ReadableEditorDialog::RunDialog);
-		GlobalEventManager().addCommand("ReadableEditorDialog", "ReadableEditorDialog");
-
 		GlobalCommandSystem().addCommand("ReloadReadables", ui::ReadableReloader::run);
-		GlobalEventManager().addCommand("ReloadReadables", "ReloadReadables");
 
-		GlobalRadiant().signal_radiantStarted().connect(
-            sigc::mem_fun(this, &GuiModule::onRadiantStartup)
+		GlobalMainFrame().signal_MainFrameConstructed().connect(
+            sigc::mem_fun(this, &GuiModule::onMainFrameConstructed)
         );
 
 		// Create the Readable Editor Preferences
 		constructPreferences();
 	}
 
-	void onRadiantStartup()
+private:
+	void onMainFrameConstructed()
 	{
 		// Add menu items on radiant startup, to ensure that all menu items are existent at this point
 		IMenuManager& mm = GlobalUIManager().getMenuManager();
@@ -123,6 +119,6 @@ extern "C" void DARKRADIANT_DLLEXPORT RegisterModule(IModuleRegistry& registry)
 {
 	module::performDefaultInitialisation(registry);
 
-	registry.registerModule(GuiModulePtr(new GuiModule));
+	registry.registerModule(std::make_shared<GuiModule>());
 	registry.registerModule(std::make_shared<gui::GuiManager>());
 }
