@@ -91,7 +91,7 @@ void ObjectivesEditor::setupEntitiesPanel()
 	wxPanel* entityPanel = findNamedObject<wxPanel>(this, "ObjDialogEntityPanel");
 
 	// Entity Tree View
-	_objectiveEntityView = wxutil::TreeView::CreateWithModel(entityPanel, _objectiveEntityList, wxDV_NO_HEADER);
+	_objectiveEntityView = wxutil::TreeView::CreateWithModel(entityPanel, _objectiveEntityList.get(), wxDV_NO_HEADER);
 	entityPanel->GetSizer()->Add(_objectiveEntityView, 1, wxEXPAND);
 
 	_objectiveEntityView->AppendToggleColumn(_("Start"), _objEntityColumns.startActive.getColumnIndex(),
@@ -124,7 +124,7 @@ void ObjectivesEditor::setupObjectivesPanel()
 	wxPanel* panel = findNamedObject<wxPanel>(this, "ObjDialogObjectivesPanel");
 
 	// Entity Tree View
-	_objectiveView = wxutil::TreeView::CreateWithModel(panel, _objectiveList);
+	_objectiveView = wxutil::TreeView::CreateWithModel(panel, _objectiveList.get());
 	panel->GetSizer()->Add(_objectiveView, 1, wxEXPAND);
 
 	// Key and value text columns
@@ -135,8 +135,8 @@ void ObjectivesEditor::setupObjectivesPanel()
 	_objectiveView->AppendTextColumn(_("Diff."), _objectiveColumns.difficultyLevel.getColumnIndex(),
 		wxDATAVIEW_CELL_INERT, wxCOL_WIDTH_AUTOSIZE, wxALIGN_NOT);
 
-	_objectiveView->Connect(wxEVT_DATAVIEW_SELECTION_CHANGED, 
-		wxDataViewEventHandler(ObjectivesEditor::_onObjectiveSelectionChanged), NULL, this);
+	_objectiveView->Bind(wxEVT_DATAVIEW_SELECTION_CHANGED, &ObjectivesEditor::_onObjectiveSelectionChanged, this);
+	_objectiveView->Bind(wxEVT_DATAVIEW_ITEM_ACTIVATED, &ObjectivesEditor::_onObjectiveActivated, this);
     
 	wxButton* addButton = findNamedObject<wxButton>(this, "ObjDialogAddObjectiveButton");
 	addButton->Connect(wxEVT_BUTTON, wxCommandEventHandler(ObjectivesEditor::_onAddObjective), NULL, this);
@@ -192,6 +192,16 @@ void ObjectivesEditor::populateWidgets()
     );
 	GlobalSceneGraph().root()->traverse(finder);
 
+    // Select the first entity in the list for convenience
+    wxDataViewItemArray children;
+    _objectiveEntityList->GetChildren(_objectiveEntityList->GetRoot(), children);
+    
+    if (!children.empty())
+    {
+        _objectiveEntityView->Select(children.front());
+        handleEntitySelectionChange();
+    }
+
 	// Set the worldspawn entity and populate the active-at-start column
 	_worldSpawn = finder.getWorldSpawn();
 	if (_worldSpawn != NULL)
@@ -331,6 +341,11 @@ void ObjectivesEditor::_onStartActiveCellToggled(wxDataViewEvent& ev)
 
 // Callback for objective entity selection changed in list box
 void ObjectivesEditor::_onEntitySelectionChanged(wxDataViewEvent& ev)
+{
+    handleEntitySelectionChange();
+}
+
+void ObjectivesEditor::handleEntitySelectionChange()
 {
 	// Clear the objectives list
 	_objectiveList->Clear();
@@ -384,6 +399,14 @@ void ObjectivesEditor::_onObjectiveSelectionChanged(wxDataViewEvent& ev)
 	updateObjectiveButtonPanel();
 }
 
+void ObjectivesEditor::_onObjectiveActivated(wxDataViewEvent& ev)
+{
+    if (ev.GetItem().IsOk())
+    {
+        doEditObjective();
+    }
+}
+
 void ObjectivesEditor::updateEditorButtonPanel()
 {
 	wxButton* delEntityButton = findNamedObject<wxButton>(this, "ObjDialogDeleteEntityButton");
@@ -500,17 +523,22 @@ void ObjectivesEditor::_onAddObjective(wxCommandEvent& ev)
 	refreshObjectivesList();
 }
 
+void ObjectivesEditor::doEditObjective()
+{
+    // Display the ComponentsDialog
+    ComponentsDialog* compDialog = new ComponentsDialog(this, getCurrentObjective());
+
+    compDialog->ShowModal(); // show and block
+    compDialog->Destroy();
+
+    // Repopulate the objective list
+    refreshObjectivesList();
+}
+
 // Edit an existing objective
 void ObjectivesEditor::_onEditObjective(wxCommandEvent& ev)
 {
-	// Display the ComponentsDialog
-	ComponentsDialog* compDialog = new ComponentsDialog(this, getCurrentObjective());
-	
-	compDialog->ShowModal(); // show and block
-	compDialog->Destroy();
-
-	// Repopulate the objective list
-	refreshObjectivesList();
+    doEditObjective();
 }
 
 void ObjectivesEditor::_onMoveUpObjective(wxCommandEvent& ev)
