@@ -49,7 +49,7 @@ public:
 		return _dependencies;
 	}
 
-	virtual void initialiseModule(const ApplicationContext& ctx) {
+	virtual void initialiseModule(const IApplicationContext& ctx) {
 		rMessage() << "ObjectivesEditorModule::initialiseModule called.\n";
 
 		// Add the callback event
@@ -57,7 +57,6 @@ public:
 			"ObjectivesEditor",
 			objectives::ObjectivesEditor::DisplayDialog
 		);
-		GlobalEventManager().addCommand("ObjectivesEditor", "ObjectivesEditor");
 
 		// Add the menu item
 		IMenuManager& mm = GlobalUIManager().getMenuManager();
