@@ -16,6 +16,7 @@
 #include "StimEditor.h"
 #include "ResponseEditor.h"
 
+#include <wx/button.h>
 #include <wx/artprov.h>
 
 namespace ui
@@ -34,11 +35,8 @@ namespace
 
 StimResponseEditor::StimResponseEditor() :
 	DialogBase(_(WINDOW_TITLE)),
-	_notebook(new wxNotebook(this, wxID_ANY)),
 	_entity(nullptr),
-	_stimEditor(new StimEditor(_notebook, _stimTypes)),
-	_responseEditor(new ResponseEditor(_notebook, _stimTypes)),
-	_customStimEditor(new CustomStimEditor(_notebook, _stimTypes))
+	_customStimEditor(nullptr)
 {
 	// Create the widgets
 	populateWindow();
@@ -85,42 +83,28 @@ int StimResponseEditor::ShowModal()
 
 void StimResponseEditor::populateWindow()
 {
-	SetSizer(new wxBoxSizer(wxVERTICAL));
-
-	_imageList.reset(new wxImageList(16, 16));
-	_notebook->SetImageList(_imageList.get());
-
-	// Stim Editor Page
-	int imageId = _imageList->Add(
-		wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + ICON_STIM + SUFFIX_EXTENSION));
+	auto mainPanel = loadNamedPanel(this, "SREditorMainPanel");
 	
-	_notebook->AddPage(_stimEditor, _("Stims"), false, imageId);
-	_stimPageNum = _notebook->FindPage(_stimEditor);
+	_notebook = findNamedObject<wxNotebook>(this, "SREditorNotebook");
 
-	// Response Editor Page
-	imageId = _imageList->Add(
-		wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + ICON_RESPONSE + SUFFIX_EXTENSION));
+	_stimEditor = std::make_unique<StimEditor>(mainPanel, _stimTypes);
+	_responseEditor = std::make_unique<ResponseEditor>(mainPanel, _stimTypes);
 	
-	_notebook->AddPage(_responseEditor, _("Responses"), false, imageId);
-	_responsePageNum = _notebook->FindPage(_responseEditor);
-
 	// Custom Stim Editor
-	imageId = _imageList->Add(
-		wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + ICON_CUSTOM_STIM));
-	
-	_notebook->AddPage(_customStimEditor, _("Custom Stims"), false, imageId);
-	_customStimPageNum = _notebook->FindPage(_customStimEditor);
+	auto customStimPanel = findNamedObject<wxPanel>(mainPanel, "SREditorCustomStimEditorContainer");
+	_customStimEditor = std::make_unique<CustomStimEditor>(customStimPanel, _stimTypes);
 
 	_notebook->Connect(wxEVT_NOTEBOOK_PAGE_CHANGED, 
 		wxBookCtrlEventHandler(StimResponseEditor::onPageChanged), nullptr, this);
 
-	// Pack everything into the main window
-	GetSizer()->Add(_notebook, 1, wxEXPAND | wxALL, 12);
-	GetSizer()->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), 0, wxALIGN_RIGHT | wxALL, 12);
+	findNamedObject<wxButton>(this, "SREditorOkButton")->Bind(
+		wxEVT_BUTTON, [this](wxCommandEvent& ev) { EndModal(wxID_OK); });
+	findNamedObject<wxButton>(this, "SREditorCancelButton")->Bind(
+		wxEVT_BUTTON, [this](wxCommandEvent& ev) { EndModal(wxID_CANCEL); });
 
 	if (_lastShownPage == -1)
 	{
-		_lastShownPage = _stimPageNum;
+		_lastShownPage = 0;
 	}
 
 	Layout();
@@ -146,8 +130,8 @@ void StimResponseEditor::rescanSelection()
 {
 	const SelectionInfo& info = GlobalSelectionSystem().getSelectionInfo();
 
-	_entity = NULL;
-	_srEntity = SREntityPtr();
+	_entity = nullptr;
+	_srEntity.reset();
 	_stimEditor->setEntity(_srEntity);
 	_responseEditor->setEntity(_srEntity);
 	_customStimEditor->setEntity(_srEntity);
