@@ -2,17 +2,8 @@
 
 #include <pybind11/pybind11.h>
 #include <pybind11/attr.h>
-#include <pybind11/stl_bind.h>
 #include <pybind11/eval.h>
 
-#if (PYBIND11_VERSION_MAJOR > 2) || (PYBIND11_VERSION_MAJOR == 2 && PYBIND11_VERSION_MINOR >= 2)
-#define DR_PYBIND_HAS_EMBED_H
-#endif
-
-#ifdef DR_PYBIND_HAS_EMBED_H
-#include <pybind11/embed.h>
-#endif
-
 #include "i18n.h"
 #include "itextstream.h"
 #include "iradiant.h"
@@ -43,6 +34,7 @@
 #include "interfaces/SelectionSetInterface.h"
 #include "interfaces/SelectionGroupInterface.h"
 #include "interfaces/CameraInterface.h"
+#include "interfaces/LayerInterface.h"
 
 #include "PythonModule.h"
 
@@ -58,41 +50,12 @@ namespace script
 {
 
 ScriptingSystem::ScriptingSystem() :
-	_outputWriter(false, _outputBuffer),
-	_errorWriter(true, _errorBuffer),
 	_initialised(false)
 {}
 
-void ScriptingSystem::addInterface(const std::string& name, const IScriptInterfacePtr& iface) {
-	// Check if exists
-	if (interfaceExists(name)) {
-		rError() << "Cannot add script interface " << name
-			<< ", this interface is already registered." << std::endl;
-		return;
-	}
-
-	// Try to insert
-	_interfaces.push_back(NamedInterface(name, iface));
-
-	if (_initialised) 
-	{
-		// Add the interface at once, all the others are already added
-		iface->registerInterface(PythonModule::GetModule(), PythonModule::GetGlobals());
-	}
-}
-
-bool ScriptingSystem::interfaceExists(const std::string& name)
+void ScriptingSystem::addInterface(const std::string& name, const IScriptInterfacePtr& iface)
 {
-	// Traverse the interface list
-	for (const NamedInterface& i : _interfaces)
-	{
-		if (i.first == name)
-		{
-			return true;
-		}
-	}
-
-	return false;
+    _pythonModule->addInterface(NamedInterface(name, iface));
 }
 
 void ScriptingSystem::executeScriptFile(const std::string& filename)
@@ -122,7 +85,7 @@ void ScriptingSystem::executeScriptFile(const std::string& filename, bool setExe
 		}
 
 		// Attempt to run the specified script
-		py::eval_file(filePath, PythonModule::GetGlobals(), locals);
+		py::eval_file(filePath, _pythonModule->getGlobals(), locals);
 	}
     catch (std::invalid_argument& e)
     {
@@ -137,38 +100,7 @@ void ScriptingSystem::executeScriptFile(const std::string& filename, bool setExe
 
 ExecutionResultPtr ScriptingSystem::executeString(const std::string& scriptString)
 {
-	ExecutionResultPtr result = std::make_shared<ExecutionResult>();
-
-	result->errorOccurred = false;
-
-	// Clear the output buffers before starting to execute
-	_outputBuffer.clear();
-	_errorBuffer.clear();
-
-	try
-	{
-		std::string fullScript = "import " + std::string(PythonModule::NAME()) + " as DR\n"
-			"from " + std::string(PythonModule::NAME()) + " import *\n";
-		fullScript.append(scriptString);
-
-		// Attempt to run the specified script
-		py::eval<py::eval_statements>(fullScript, PythonModule::GetGlobals());
-	}
-	catch (py::error_already_set& ex)
-	{
-		_errorBuffer.append(ex.what());
-		result->errorOccurred = true;
-
-		rError() << "Error executing script: " << ex.what() << std::endl;
-	}
-
-	result->output += _outputBuffer + "\n";
-	result->output += _errorBuffer + "\n";
-
-	_outputBuffer.clear();
-	_errorBuffer.clear();
-
-	return result;
+    return _pythonModule->executeString(scriptString);
 }
 
 void ScriptingSystem::foreachScriptCommand(const std::function<void(const IScriptCommand&)>& functor)
@@ -186,57 +118,10 @@ sigc::signal<void>& ScriptingSystem::signal_onScriptsReloaded()
 	return _sigScriptsReloaded;
 }
 
-void ScriptingSystem::addInterfacesToModule(py::module& mod, py::dict& globals)
-{
-	// Add the registered interfaces
-	for (NamedInterface& i : _interfaces)
-	{
-		// Handle each interface in its own try/catch block
-		try
-		{
-			i.second->registerInterface(mod, globals);
-		}
-		catch (const py::error_already_set& ex)
-		{
-			rError() << "Error while initialising interface " << i.first << ": " << std::endl;
-			rError() << ex.what() << std::endl;
-		}
-	}
-}
-
 void ScriptingSystem::initialise()
 {
-	// The finalize_interpreter() function is not available in older versions
-#ifdef DR_PYBIND_HAS_EMBED_H
-	py::initialize_interpreter();
-#else
-	Py_Initialize();
-#endif
-
-	{
-		try
-		{
-			// Import the darkradiant module
-			py::module::import(PythonModule::NAME());
-
-			// Construct the console writer interface
-			PythonConsoleWriterClass consoleWriter(PythonModule::GetModule(), "PythonConsoleWriter");
-			consoleWriter.def(py::init<bool, std::string&>());
-			consoleWriter.def("write", &PythonConsoleWriter::write);
-			consoleWriter.def("flush", &PythonConsoleWriter::flush);
-
-			// Redirect stdio output to our local ConsoleWriter instances
-			py::module::import("sys").attr("stderr") = &_errorWriter;
-			py::module::import("sys").attr("stdout") = &_outputWriter;
-
-			// String vector is used in multiple places
-			py::bind_vector< std::vector<std::string> >(PythonModule::GetModule(), "StringVector");
-		}
-		catch (const py::error_already_set& ex)
-		{
-			rError() << ex.what() << std::endl;
-		}
-	}
+    // Fire up the interpreter
+    _pythonModule->initialise();
 
 	_initialised = true;
 
@@ -302,7 +187,7 @@ void ScriptingSystem::loadCommandScript(const std::string& scriptFilename)
 		locals["__executeCommand__"] = false;
 
 		// Attempt to run the specified script
-		py::eval_file(_scriptPath + scriptFilename, PythonModule::GetGlobals(), locals);
+		py::eval_file(_scriptPath + scriptFilename, _pythonModule->getGlobals(), locals);
 
 		std::string cmdName;
 		std::string cmdDisplayName;
@@ -415,15 +300,10 @@ void ScriptingSystem::initialiseModule(const IApplicationContext& ctx)
 		.connect(sigc::mem_fun(this, &ScriptingSystem::initialise));
 
 	// Construct the script path
-#if defined(POSIX) && defined(PKGLIBDIR)
-	_scriptPath = std::string(PKGLIBDIR) + "/scripts/";
-#else
 	_scriptPath = ctx.getRuntimeDataPath() + "scripts/";
-#endif
 
-	// When Python asks for the object, let's register our interfaces to the py::module
-	PythonModule::RegisterToPython(
-		std::bind(&ScriptingSystem::addInterfacesToModule, this, std::placeholders::_1, std::placeholders::_2));
+	// Set up the python interpreter
+    _pythonModule.reset(new PythonModule);
 
 	// Add the built-in interfaces (the order is important, as we don't have dependency-resolution yet)
 	addInterface("Math", std::make_shared<MathInterface>());
@@ -448,6 +328,7 @@ void ScriptingSystem::initialiseModule(const IApplicationContext& ctx)
 	addInterface("SelectionSetInterface", std::make_shared<SelectionSetInterface>());
 	addInterface("SelectionGroupInterface", std::make_shared<SelectionGroupInterface>());
 	addInterface("CameraInterface", std::make_shared<CameraInterface>());
+	addInterface("LayerInterface", std::make_shared<LayerInterface>());
 
 	GlobalCommandSystem().addCommand(
 		"RunScript",
@@ -484,17 +365,7 @@ void ScriptingSystem::shutdownModule()
 
 	_scriptPath.clear();
 
-	// Free all interfaces
-	_interfaces.clear();
-
-	PythonModule::Clear();
-
-	// The finalize_interpreter() function is not available in older versions
-#ifdef DR_PYBIND_HAS_EMBED_H
-	py::finalize_interpreter();
-#else 
-	Py_Finalize();
-#endif
+    _pythonModule.reset();
 }
 
 } // namespace script
