@@ -11,7 +11,7 @@ class PopupErrorHandler
 public:
 	static void HandleError(const std::string& title, const std::string& msg)
 	{
-		if (wxutil::Messagebox::Show(title, msg, ui::IDialog::MESSAGE_ASK) == ui::IDialog::RESULT_YES)
+		if (wxutil::Messagebox::Show(title, msg, ui::IDialog::MESSAGE_ASK, nullptr) == ui::IDialog::RESULT_YES)
 		{
 			DEBUGGER_BREAKPOINT();
 		}
