@@ -59,6 +59,7 @@
 #include "ui/brush/QuerySidesDialog.h"
 #include "ui/brush/FindBrush.h"
 #include "ui/mousetool/RegistrationHelper.h"
+#include "ui/mapselector/MapSelector.h"
 
 #include <wx/version.h>
 
@@ -123,9 +124,9 @@ void UserInterfaceModule::initialiseModule(const IApplicationContext& ctx)
 	// Register LayerControlDialog
 	GlobalCommandSystem().addCommand("ToggleLayerControlDialog", LayerControlDialog::toggle);
 
-	// Create a new menu item connected to the CreateNewLayer command
+	// Create a new menu item connected to the CreateNewLayerDialog command
 	GlobalOrthoContextMenu().addItem(std::make_shared<wxutil::CommandMenuItem>(
-			new wxutil::IconTextMenuItem(_(CREATE_LAYER_TEXT), LAYER_ICON), "CreateNewLayer"),
+			new wxutil::IconTextMenuItem(_(CREATE_LAYER_TEXT), LAYER_ICON), "CreateNewLayerDialog"),
 		IOrthoContextMenu::SECTION_LAYER
 	);
 
@@ -181,11 +182,11 @@ void UserInterfaceModule::initialiseModule(const IApplicationContext& ctx)
 		[]() { return cmd::ExecutionNotPossible::ToBool(selection::checkUngroupSelectedAvailable); }),
 		IOrthoContextMenu::SECTION_SELECTION_GROUPS);
 
-	_eClassColourManager.reset(new EntityClassColourManager);
 	_longOperationHandler.reset(new LongRunningOperationHandler);
 	_mapFileProgressHandler.reset(new MapFileProgressHandler);
 	_autoSaveRequestHandler.reset(new AutoSaveRequestHandler);
 	_fileSelectionRequestHandler.reset(new FileSelectionRequestHandler);
+    _fileOverwriteConfirmationHandler.reset(new FileOverwriteConfirmationHandler);
 
 	initialiseEntitySettings();
 
@@ -230,8 +231,8 @@ void UserInterfaceModule::shutdownModule()
 	_entitySettingsConn.disconnect();
 
 	_longOperationHandler.reset();
-	_eClassColourManager.reset();
 	_mapFileProgressHandler.reset();
+    _fileOverwriteConfirmationHandler.reset();
 	_fileSelectionRequestHandler.reset();
 	_autoSaveRequestHandler.reset();
 	_shaderClipboardStatus.reset();
@@ -386,7 +387,7 @@ void UserInterfaceModule::registerUICommands()
 	GlobalCommandSystem().addCommand("ParticlesEditor", ParticleEditor::DisplayDialog);
 
 	// Register the "create layer" command
-	GlobalCommandSystem().addCommand("CreateNewLayer", CreateLayerDialog::CreateNewLayer,
+	GlobalCommandSystem().addCommand("CreateNewLayerDialog", CreateLayerDialog::CreateNewLayer,
 		{ cmd::ARGTYPE_STRING | cmd::ARGTYPE_OPTIONAL });
 
 	GlobalCommandSystem().addCommand("BulgePatchDialog", BulgePatchDialog::BulgePatchCmd);
@@ -408,6 +409,7 @@ void UserInterfaceModule::registerUICommands()
 	GlobalEventManager().addRegistryToggle("TogTexLock", RKEY_ENABLE_TEXTURE_LOCK);
 
 	GlobalCommandSystem().addCommand("LoadPrefab", ui::loadPrefabDialog);
+	GlobalCommandSystem().addCommand("OpenMapFromProject", ui::MapSelector::OpenMapFromProject);
 }
 
 void UserInterfaceModule::HandleTextureChanged(radiant::TextureChangedMessage& msg)
