@@ -5,6 +5,7 @@
 #include "iuimanager.h"
 #include "iscenegraphfactory.h"
 #include "math/AABB.h"
+#include "scene/PrefabBoundsAccumulator.h"
 
 namespace ui
 {
@@ -29,10 +30,11 @@ void MapPreview::setRootNode(const scene::IMapRootNodePtr& root)
         resetModelRotation();
 
 		// Calculate camera distance so map is appropriately zoomed
-        double distance = getScene()->root()->worldAABB().getRadius() * 2.0f;
+        auto sceneBounds = getSceneBounds();
+        auto distance = sceneBounds.getRadius() * 3.0f;
 
-        setViewOrigin(Vector3(1, 1, 1) * distance);
-        setViewAngles(Vector3(34, 135, 0));
+        setViewOrigin(sceneBounds.getOrigin() + Vector3(-0.5, -0.8, 0.4) * distance);
+        setViewAngles(Vector3(26, 300, 0));
 	}
 }
 
@@ -45,7 +47,10 @@ AABB MapPreview::getSceneBounds()
 {
 	if (!getScene()->root()) return RenderPreview::getSceneBounds();
 
-	return getScene()->root()->worldAABB();
+    scene::PrefabBoundsAccumulator accumulator;
+    getScene()->root()->traverseChildren(accumulator);
+
+	return accumulator.getBounds();
 }
 
 bool MapPreview::onPreRender()
