@@ -31,13 +31,19 @@ BooleanPropertyEditor::BooleanPropertyEditor(wxWindow* parent, Entity* entity,
 	// Create the checkbox with correct initial state, and connect up the
 	// toggle callback
 	_checkBox = new wxCheckBox(mainVBox, wxID_ANY, name);
-	_checkBox->SetValue(_entity->getKeyValue(_key) == "1");
+
+	updateFromEntity();
 
 	_checkBox->Connect(wxEVT_CHECKBOX, wxCommandEventHandler(BooleanPropertyEditor::_onToggle), NULL, this);
 
 	mainVBox->GetSizer()->Add(_checkBox, 0, wxALIGN_CENTER_VERTICAL);
 }
 
+void BooleanPropertyEditor::updateFromEntity()
+{
+	_checkBox->SetValue(_entity->getKeyValue(_key) == "1");
+}
+
 void BooleanPropertyEditor::_onToggle(wxCommandEvent& ev)
 {
 	// Set the key based on the checkbutton state
