@@ -4,14 +4,14 @@
 #include "i18n.h"
 #include "ientity.h"
 #include "iundo.h"
+#include "icommandsystem.h"
 
 #include <wx/panel.h>
 #include <wx/button.h>
 #include <wx/sizer.h>
-#include "wxutil/dialog/MessageBox.h"
+#include "wxutil/EntityClassChooser.h"
 
-#include "selection/algorithm/Entity.h"
-#include "ui/entitychooser/EntityClassChooser.h"
+#include "command/ExecutionFailure.h"
 
 namespace ui
 {
@@ -32,22 +32,13 @@ void ClassnamePropertyEditor::onBrowseButtonClick()
 	std::string currentEclass = _entity->getKeyValue(_key);
 
 	// Use the EntityClassChooser dialog to get a selection from the user
-	std::string selection = EntityClassChooser::chooseEntityClass(currentEclass);
+	std::string selection = wxutil::EntityClassChooser::chooseEntityClass(currentEclass);
 
 	// Only apply if the classname has actually changed
 	if (!selection.empty() && selection != currentEclass)
 	{
-		UndoableCommand cmd("changeEntityClass");
-
-		try
-		{
-			// Apply the classname change to the entity, this requires some algorithm
-			selection::algorithm::setEntityClassname(selection);
-		}
-		catch (std::runtime_error& ex)
-		{
-			wxutil::Messagebox::ShowError(ex.what());
-		}
+		// Apply the classname change to the current selection, dispatch the command
+		GlobalCommandSystem().executeCommand("SetEntityKeyValue", _key, selection);
 	}
 }
 
