@@ -8,7 +8,7 @@
 #include "wxutil/preview/ModelPreview.h"
 #include <string>
 
-#include "wxutil/TreeModel.h"
+#include "wxutil/dataview/TreeModel.h"
 
 namespace wxutil { class TreeView; }
 
@@ -58,6 +58,9 @@ private:
 	// Model preview widget
     wxutil::ModelPreviewPtr _preview;
 
+    wxDataViewItem _allSkinsItem;
+    wxDataViewItem _matchingSkinsItem;
+
 private:
 	// Constructor creates widgets
 	SkinChooser();
