@@ -39,10 +39,12 @@ public:
 	// Construct a blank TextPropertyEditor for use in the PropertyEditorFactory
 	Vector3PropertyEditor();
 
+	void updateFromEntity() override;
+
 	// Create a new TextPropertyEditor
     virtual IPropertyEditorPtr createNew(wxWindow* parent, Entity* entity,
     									const std::string& name,
-    									const std::string& options)
+    									const std::string& options) override
 	{
     	return PropertyEditorPtr(new Vector3PropertyEditor(parent, entity, name));
     }
