@@ -10,7 +10,7 @@
 #include "icameraview.h"
 #include "i18n.h"
 
-#include "wxutil/TreeView.h"
+#include "wxutil/dataview/TreeView.h"
 
 #include <wx/sizer.h>
 #include <wx/checkbox.h>
