@@ -2,11 +2,13 @@
 
 #include <wx/event.h>
 #include <memory>
+#include <wx/colour.h>
 
 class wxWindow;
 class wxButton;
 class wxToggleButton;
 class wxSizer;
+class wxPanel;
 
 namespace ui
 {
@@ -26,11 +28,15 @@ private:
 	int _layerID;
 
 	wxToggleButton* _toggle;
+	wxPanel* _statusWidget;
 	wxButton* _labelButton;
 	wxButton* _deleteButton;
 	wxButton* _renameButton;
 	wxSizer* _buttonHBox;
 
+	wxColour _activeColour;
+	wxColour _inactiveColour;
+
 	// Locks down the callbacks during widget update
 	bool _updateActive;
 
@@ -39,12 +45,18 @@ public:
 
 	// Returns the widgets for packing this object into a container/table
 	wxButton* getLabelButton();
+	wxWindow* getStatusWidget();
 	wxSizer* getButtons();
 	wxToggleButton* getToggle();
 
-	// Updates the state of all widgets
+	// Updates the state of all widgets, 
+	// except for the usage status widget which is reset to the "inactive" default
 	void update();
 
+	int getLayerId() const;
+
+	void updateUsageStatusWidget(std::size_t numUsedObjectsInLayer);
+
 private:
 	void onToggle(wxCommandEvent& ev);
 	void onDelete(wxCommandEvent& ev);
