@@ -13,7 +13,7 @@
 
 #include "log/Console.h"
 #include "xyview/GlobalXYWnd.h"
-#include "camera/GlobalCameraWndManager.h"
+#include "camera/CameraWndManager.h"
 
 #include "registry/registry.h"
 #include "wxutil/MultiMonitor.h"
@@ -354,6 +354,7 @@ void MainFrame::onTopLevelFrameClose(wxCloseEvent& ev)
 	
     // Destroy the actual window
     _topLevelWindow->Destroy();
+    _topLevelWindow = nullptr;
 
     // wxWidgets is supposed to quit when the main window is destroyed, but
     // it doesn't so we need to exit the main loop manually. Probably we
@@ -369,7 +370,7 @@ wxFrame* MainFrame::getWxTopLevelWindow()
 
 wxBoxSizer* MainFrame::getWxMainContainer()
 {
-	return _topLevelWindow != NULL ? _topLevelWindow->getMainContainer() : NULL;
+	return _topLevelWindow != nullptr ? _topLevelWindow->getMainContainer() : nullptr;
 }
 
 bool MainFrame::isActiveApp()
@@ -431,7 +432,16 @@ void MainFrame::restoreWindowPosition()
 
 wxToolBar* MainFrame::getToolbar(IMainFrame::Toolbar type)
 {
-	return _topLevelWindow->getToolbar(type);
+    // Pass any request for the camera view toolbar to the active CamWnd, if
+    // any
+    if (type == Toolbar::CAMERA)
+    {
+        CamWndPtr cw = GlobalCamera().getActiveCamWnd();
+        return cw ? cw->getToolbar() : nullptr;
+    }
+
+    // Main window toolbar
+    return _topLevelWindow->getToolbar(type);
 }
 
 void MainFrame::create()
