@@ -1,10 +1,14 @@
 #pragma once
 
 #include "iuimanager.h"
-#include "wxutil/VFSTreePopulator.h"
+#include "wxutil/dataview/VFSTreePopulator.h"
+#include "wxutil/dataview/TreeViewItemStyle.h"
+#include "ifavourites.h"
 #include "ModelSelector.h"
 #include <wx/artprov.h>
 
+#include "ModelTreeView.h"
+
 namespace ui
 {
 
@@ -14,8 +18,6 @@ namespace
 	const char* MODEL_ICON = "model16green.png";
 	const char* SKIN_ICON = "skin16.png";
 	const char* FOLDER_ICON = "folder16.png";
-
-	const char* MODELS_FOLDER = "models/";
 }
 
 /**
@@ -26,7 +28,7 @@ class ModelDataInserter :
 	public wxutil::VFSTreePopulator::Visitor
 {
 private:
-	const ModelSelector::TreeColumns& _columns;
+	const ModelTreeView::TreeColumns& _columns;
 
 	bool _includeSkins;
 
@@ -34,17 +36,22 @@ private:
 	wxIcon _folderIcon;
 	wxIcon _skinIcon;
 
+    std::set<std::string> _favourites;
+
 public:
 	/**
 	 * greebo: Pass TRUE to the constructor to add skins to the store.
 	 */
-	ModelDataInserter(const ModelSelector::TreeColumns& columns, bool includeSkins) :
+	ModelDataInserter(const ModelTreeView::TreeColumns& columns, bool includeSkins) :
 		_columns(columns),
 		_includeSkins(includeSkins)
 	{
 		_modelIcon.CopyFromBitmap(wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + MODEL_ICON));
 		_folderIcon.CopyFromBitmap(wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + FOLDER_ICON));
 		_skinIcon.CopyFromBitmap(wxArtProvider::GetBitmap(GlobalUIManager().ArtIdPrefix() + SKIN_ICON));
+
+        // Get the list of favourites
+        _favourites = GlobalFavouritesManager().getFavourites(decl::Type::Model);
 	}
 
 	virtual ~ModelDataInserter() {}
@@ -60,14 +67,21 @@ public:
 		std::string displayName = path.substr(path.rfind("/") + 1);
 
 		// Pathname is the model VFS name for a model, and blank for a folder
-		std::string fullPath = isExplicit ? (MODELS_FOLDER + path) : "";
+		std::string fullPath = isExplicit ? path : "";
+
+        bool isFavourite = isExplicit && _favourites.count(fullPath) > 0;
 
 		// Pixbuf depends on model type
-		row[_columns.filename] = wxVariant(wxDataViewIconText(displayName, isExplicit ? _modelIcon : _folderIcon));
-		row[_columns.vfspath] = fullPath;
+		row[_columns.iconAndName] = wxVariant(wxDataViewIconText(displayName, isExplicit ? _modelIcon : _folderIcon));
+        row[_columns.iconAndName] = wxutil::TreeViewItemStyle::Declaration(isFavourite); // assign attributes
+		row[_columns.fullName] = fullPath;
+		row[_columns.modelPath] = fullPath;
+		row[_columns.leafName] = displayName;
 		row[_columns.skin] = std::string();
         row[_columns.isSkin] = false;
 		row[_columns.isFolder] = !isExplicit;
+		row[_columns.isFavourite] = isFavourite;
+        row[_columns.isModelDefFolder] = false;
 
 		if (!_includeSkins) return; // done
 
@@ -75,17 +89,23 @@ public:
 		// children if so
 		const StringList& skinList = GlobalModelSkinCache().getSkinsForModel(fullPath);
 
-		for (StringList::const_iterator i = skinList.begin();
-			 i != skinList.end();
-			 ++i)
+		for (const auto& skinName : skinList)
 		{
 			wxutil::TreeModel::Row skinRow = store.AddItem(row.getItem());
 
-			skinRow[_columns.filename] = wxVariant(wxDataViewIconText(*i, _skinIcon));
-			skinRow[_columns.vfspath] = fullPath;
-			skinRow[_columns.skin] = *i;
+            auto fullSkinPath = fullPath + "/" + skinName;
+            isFavourite = isExplicit && _favourites.count(fullSkinPath) > 0;
+
+			skinRow[_columns.iconAndName] = wxVariant(wxDataViewIconText(skinName, _skinIcon));
+            skinRow[_columns.iconAndName] = wxutil::TreeViewItemStyle::Declaration(isFavourite); // assign attributes
+			skinRow[_columns.fullName] = fullSkinPath; // model path + skin
+			skinRow[_columns.modelPath] = fullPath; // this is the model path
+			skinRow[_columns.leafName] = skinName;
+			skinRow[_columns.skin] = skinName;
             skinRow[_columns.isSkin] = true;
 			skinRow[_columns.isFolder] = false;
+            skinRow[_columns.isFavourite] = isFavourite;
+            skinRow[_columns.isModelDefFolder] = false;
 		}
 	}
 };
