@@ -3,13 +3,15 @@
 #include "i18n.h"
 #include "imainframe.h"
 #include "string/convert.h"
+#include "selectionlib.h"
+#include "wxutil/dialog/MessageBox.h"
 
 namespace
 {
 	const char* WINDOW_TITLE = N_("Bulge Patch");
 	const char* LABEL_NOISE = N_("Noise:");
 
-	const int NOISE = 16;
+	const float NOISE = 16;
 }
 
 namespace ui {
@@ -22,7 +24,7 @@ BulgePatchDialog::BulgePatchDialog() :
 	setElementValue(_noiseHandle, string::to_string(NOISE));
 }
 
-bool BulgePatchDialog::QueryPatchNoise(int& noise)
+bool BulgePatchDialog::QueryPatchNoise(float& noise)
 {
 	// Instantiate a dialog and run the dialog routine
 	BulgePatchDialog* dialog = new BulgePatchDialog;
@@ -40,4 +42,21 @@ bool BulgePatchDialog::QueryPatchNoise(int& noise)
 	return false; // cancelled
 }
 
+void BulgePatchDialog::BulgePatchCmd(const cmd::ArgumentList& args)
+{
+	if (GlobalSelectionSystem().getSelectionInfo().patchCount == 0)
+	{
+		wxutil::Messagebox::ShowError(_("Cannot bulge patch. No patches selected."));
+		return;
+	}
+
+	float maxValue = NOISE;
+
+	// Ask the user to enter a noise value and dispatch to the algorithm
+	if (QueryPatchNoise(maxValue))
+	{
+		GlobalCommandSystem().executeCommand("BulgePatch", cmd::Argument(maxValue));
+	}
+}
+
 } // namespace
