@@ -3,13 +3,17 @@
 #include "i18n.h"
 #include "igrid.h"
 #include "iclipper.h"
+#include "iselection.h"
 #include "imainframe.h"
-#include "selection/algorithm/General.h"
 #include "XYMouseToolEvent.h"
 
 namespace ui
 {
 
+ClipperTool::ClipperTool() :
+    _crossHairEnabled(false)
+{}
+
 const std::string& ClipperTool::getName()
 {
     static std::string name("ClipperTool");
@@ -37,7 +41,7 @@ MouseTool::Result ClipperTool::onMouseDown(Event& ev)
 
             GlobalClipper().setMovingClip(foundClipPoint);
 
-            if (foundClipPoint == NULL)
+            if (foundClipPoint == nullptr)
             {
                 dropClipPoint(xyEvent);
             }
@@ -61,14 +65,30 @@ MouseTool::Result ClipperTool::onMouseMove(Event& ev)
 
         if (!GlobalClipper().clipMode())
         {
+            // Check if we need to clean up the XY cursor state
+            if (_crossHairEnabled)
+            {
+                xyEvent.getView().setCursorType(IOrthoView::CursorType::Default);
+                _crossHairEnabled = false;
+            }
+
             return Result::Ignored;
         }
 
         // Check, if we have a clip point operation running
-        if (GlobalClipper().getMovingClip() != NULL)
+        if (GlobalClipper().getMovingClip() != nullptr)
         {
-            GlobalClipper().getMovingClipCoords() = xyEvent.getWorldPos();
-            xyEvent.getView().snapToGrid(GlobalClipper().getMovingClipCoords());
+            // Leave the third coordinate of the clip point untouched (#5356)
+            auto viewType = xyEvent.getViewType();
+            int missingDim = viewType == XY ? 2 : viewType == YZ ? 0 : 1;
+            auto& clipCoords = GlobalClipper().getMovingClipCoords();
+            
+            Vector3 newWorldPos = xyEvent.getWorldPos();
+            newWorldPos[missingDim] = clipCoords[missingDim];
+
+            xyEvent.getView().snapToGrid(newWorldPos);
+
+            GlobalClipper().getMovingClipCoords() = newWorldPos;
             GlobalClipper().update();
 
             GlobalMainFrame().updateAllWindows();
@@ -80,11 +100,14 @@ MouseTool::Result ClipperTool::onMouseMove(Event& ev)
         if (GlobalClipper().find(xyEvent.getWorldPos(), xyEvent.getViewType(), xyEvent.getScale()) != NULL)
         {
             xyEvent.getView().setCursorType(IOrthoView::CursorType::Crosshair);
+            // Remember to clean up the cursor when clip mode is deactivated
+            _crossHairEnabled = true;
             return Result::Continued;
         }
         else
         {
             xyEvent.getView().setCursorType(IOrthoView::CursorType::Default);
+            _crossHairEnabled = false;
             return Result::Continued;
         }
     }
@@ -123,7 +146,7 @@ bool ClipperTool::alwaysReceivesMoveEvents()
 void ClipperTool::dropClipPoint(XYMouseToolEvent& event)
 {
     Vector3 point = event.getWorldPos();
-    Vector3 mid = selection::algorithm::getCurrentSelectionCenter();
+    Vector3 mid = GlobalSelectionSystem().getCurrentSelectionCenter();
 
     GlobalClipper().setViewType(static_cast<EViewType>(event.getViewType()));
     int nDim = (GlobalClipper().getViewType() == YZ) ? 0 : ((GlobalClipper().getViewType() == XZ) ? 1 : 2);
