@@ -41,7 +41,8 @@ public:
     {
         try
         {
-            dynamic_cast<XYMouseToolEvent&>(ev);
+            // Perform a dynamic cast to ensure we're on the correct view
+            dynamic_cast<XYMouseToolEvent&>(ev).getScale();
 
             _dragZoom = 0;
 
@@ -94,7 +95,7 @@ public:
         try
         {
             // We only operate on XY view events, so attempt to cast
-            dynamic_cast<XYMouseToolEvent&>(ev);
+            dynamic_cast<XYMouseToolEvent&>(ev).getScale();
             return Result::Finished;
         }
         catch (std::bad_cast&)
