@@ -224,14 +224,6 @@ bool Face::intersectVolume(const VolumeTest& volume, const Matrix4& localToWorld
     }
 }
 
-void Face::renderSolid(RenderableCollector& collector,
-                       const Matrix4& localToWorld, const IRenderEntity& entity,
-                       const LightSources& lights) const
-{
-    collector.addRenderable(*_shader.getGLShader(), m_winding, localToWorld,
-                            &lights, &entity);
-}
-
 void Face::renderWireframe(RenderableCollector& collector, const Matrix4& localToWorld,
     const IRenderEntity& entity) const
 {
