@@ -10,6 +10,7 @@
 #include "idialogmanager.h"
 #include "ieventmanager.h"
 #include "imodel.h"
+#include "igrid.h"
 #include "ifilesystem.h"
 #include "ifiletypes.h"
 #include "iselectiongroup.h"
@@ -32,6 +33,7 @@
 
 #include "brush/BrushModule.h"
 #include "scene/BasicRootNode.h"
+#include "scene/PrefabBoundsAccumulator.h"
 #include "map/MapFileManager.h"
 #include "map/MapPositionManager.h"
 #include "map/MapResource.h"
@@ -653,12 +655,18 @@ void Map::loadPrefabAt(const cmd::ArgumentList& args)
         // Now import the prefab (imported items get selected)
 		import(prefabPath);
 
+        // Get the selection bounds, snap its origin to the grid
+        scene::PrefabBoundsAccumulator accumulator;
+        GlobalSelectionSystem().foreachSelected(accumulator);
+
+        auto prefabCenter = accumulator.getBounds().getOrigin().getSnapped(GlobalGrid().getGridSize());
+
         // Switch texture lock on
         bool prevTexLockState = GlobalBrush().textureLockEnabled();
         GlobalBrush().setTextureLock(true);
 
         // Translate the selection to the given point
-        selection::algorithm::translateSelected(targetCoords);
+        selection::algorithm::translateSelected(targetCoords - prefabCenter);
 
         // Revert to previous state
         GlobalBrush().setTextureLock(prevTexLockState);
