@@ -3,6 +3,7 @@
 #include "i18n.h"
 #include "iundo.h"
 #include "igrid.h"
+#include "igl.h"
 #include "iselectiongroup.h"
 #include "iradiant.h"
 #include "ieventmanager.h"
@@ -30,6 +31,12 @@
 namespace selection
 {
 
+namespace
+{
+    const std::string RKEY_MANIPULATOR_FONTSTYLE = "user/ui/manipulatorFontStyle";
+    const std::string RKEY_MANIPULATOR_FONTSIZE = "user/ui/manipulatorFontSize";
+}
+
 // --------- RadiantSelectionSystem Implementation ------------------------------------------
 
 RadiantSelectionSystem::RadiantSelectionSystem() :
@@ -862,10 +869,15 @@ const Matrix4& RadiantSelectionSystem::getPivot2World()
 
 void RadiantSelectionSystem::captureShaders()
 {
+    auto manipulatorFontStyle = registry::getValue<std::string>(RKEY_MANIPULATOR_FONTSTYLE) == "Sans" ?
+        IGLFont::Style::Sans : IGLFont::Style::Mono;
+    auto manipulatorFontSize = registry::getValue<int>(RKEY_MANIPULATOR_FONTSIZE);
+
     TranslateManipulator::_stateWire = GlobalRenderSystem().capture("$WIRE_OVERLAY");
     TranslateManipulator::_stateFill = GlobalRenderSystem().capture("$FLATSHADE_OVERLAY");
     RotateManipulator::_stateOuter = GlobalRenderSystem().capture("$WIRE_OVERLAY");
 	RotateManipulator::_pivotPointShader = GlobalRenderSystem().capture("$POINT");
+	RotateManipulator::_glFont = GlobalOpenGL().getFont(manipulatorFontStyle, manipulatorFontSize);
 	ModelScaleManipulator::_lineShader = GlobalRenderSystem().capture("$WIRE_OVERLAY");
 	ModelScaleManipulator::_pointShader = GlobalRenderSystem().capture("$POINT");
 }
@@ -874,6 +886,7 @@ void RadiantSelectionSystem::releaseShaders()
 {
     TranslateManipulator::_stateWire.reset();
     TranslateManipulator::_stateFill.reset();
+    RotateManipulator::_glFont.reset();
 	RotateManipulator::_stateOuter.reset();
 	RotateManipulator::_pivotPointShader.reset();
     ModelScaleManipulator::_lineShader.reset();
@@ -958,6 +971,7 @@ const StringSet& RadiantSelectionSystem::getDependencies() const
         _dependencies.insert(MODULE_SCENEGRAPH);
 		_dependencies.insert(MODULE_MAP);
 		_dependencies.insert(MODULE_PREFERENCESYSTEM);
+		_dependencies.insert(MODULE_OPENGL);
     }
 
     return _dependencies;
